@@ -1,3 +1,97 @@
+# Helping function for processing user constants that were logged as rows
+process_user_constant_rows_6800_excel <- function(licor_file) {
+    # User constants are included as two sequential rows. The first row has a
+    # character value in its first column, and the second row has NA in its
+    # first column. This can be used to identify the first row in each pair.
+    uc_rows <- sapply(seq_len(nrow(licor_file) - 1), function(i) {
+        !is.na(licor_file[i, 1]) && is.character(licor_file[i, 1]) && is.na(licor_file[i + 1, 1])
+    })
+
+    # Get the indices of user constant rows
+    uc_row_indx <- which(uc_rows)
+
+    # Process the user constant rows if there are any
+    if (length(uc_row_indx) > 0) {
+        # Update the main table following each user constant row
+        for (i in uc_row_indx) {
+            # The first column of the first row contains the category
+            uc_category <- licor_file[i, 1]
+
+            # The second column of the first row contains the name
+            uc_name <- licor_file[i, 2]
+
+            # The second column of the second row contains the value
+            uc_val <- licor_file[i + 1, 2]
+
+            # If this column is present in the main data table, update its value
+            # in this row and all following rows
+            uc_exists <- uc_name %in% colnames(licor_file) &&
+                licor_file[['categories']][[uc_name]] == uc_category
+
+            if (uc_exists) {
+                new_vals                           <- licor_file[, uc_name]
+                new_vals[seq(i, nrow(licor_file))] <- uc_val
+                licor_file[, uc_name]              <- new_vals
+            }
+        }
+
+        # Remove the user constant rows from the data table
+        all_uc_rows <- rep_len(FALSE, nrow(licor_file))
+
+        all_uc_rows[uc_row_indx]     <- TRUE
+        all_uc_rows[uc_row_indx + 1] <- TRUE
+
+        licor_file <- licor_file[!all_uc_rows, , TRUE]
+
+        # Make sure there are no row names
+        rownames(licor_file$main_data) <- NULL
+
+        # The user-constant rows may have prevented some columns from being
+        # properly identified as having numeric values, so try to convert them
+        # again
+        for (i in seq_len(ncol(licor_file))) {
+            licor_file[['main_data']][, i] <-
+                try_as_numeric(licor_file[['main_data']][, i])
+        }
+    }
+
+    # Return the (potentially) modified version of the exdf object
+    licor_file
+}
+
+# Helping function for extracting one row of the preamble data and returning it
+# as an exdf object
+extract_6800_excel_preamble_row <- function(preamble_df, start_indx) {
+    # Initialize a placeholder data frame
+    pr <- as.data.frame(matrix(nrow = 1, ncol = ncol(preamble_df)))
+
+    # Read the column values
+    pr[1, ] <- replace_unicode(preamble_df[start_indx + 1, ])
+
+    # Read the column names
+    colnames(pr) <- replace_unicode(preamble_df[start_indx, ])
+
+    # Remove any empty columns
+    pr <- pr[!is.na(colnames(pr))]
+
+    # Convert the data to numeric values whenever possible
+    pr <- as.data.frame(
+        lapply(pr, try_as_numeric),
+        stringsAsFactors = FALSE
+    )
+
+    # The first column indicates the category
+    pr_category <- colnames(pr)[1]
+    pr[, 1] <- NULL
+
+    # Form a data frame with the categories
+    pr_category_df <- pr
+    pr_category_df[1, ] <- pr_category
+
+    # Create and return an exdf; the preamble rows do not specify units
+    exdf(pr, categories = pr_category_df)
+}
+
 read_licor_6800_Excel <- function(
     file_name,
     column_name = 'obs',
@@ -80,20 +174,14 @@ read_licor_6800_Excel <- function(
     # Get the raw preamble data
     raw_preamble <- rawdata[seq_len(data_row - 2), ]
 
-    # Define a helping function for extracting one row of the preamble data
-    extract_preamble_row <- function(start_indx) {
-        pr <- as.data.frame(matrix(nrow = 1, ncol = ncol(raw_preamble)))
-        pr[1, ] <- replace_unicode(raw_preamble[start_indx + 1, ])
-        colnames(pr) <- replace_unicode(raw_preamble[start_indx, ])
-        pr[!is.na(colnames(pr))]
-    }
-
-    # Get all the rows and combine them into one data frame
-    row_df_list <- lapply(
+    # Get all the preamble rows as exdf objects
+    row_exdf_list <- lapply(
         seq(1, nrow(raw_preamble), by = 2),
-        extract_preamble_row
+        function(i) {extract_6800_excel_preamble_row(raw_preamble, i)}
     )
-    licor_preamble <- do.call(cbind, row_df_list)
+
+    # Combine preamble rows into one exdf object
+    licor_preamble <- do.call(cbind, row_exdf_list)
 
     # Get the remarks, if possible
     if (has_remarks) {
@@ -141,14 +229,18 @@ read_licor_6800_Excel <- function(
 
     # Create the exdf object
     exdf_obj <- exdf(
-        licor_data,
-        licor_variable_units,
-        licor_variable_categories,
-        preamble = cbind(remarks, licor_preamble),
+        cbind(licor_data,                licor_preamble$main_data),
+        cbind(licor_variable_units,      licor_preamble$units),
+        cbind(licor_variable_categories, licor_preamble$categories),
+        preamble = licor_preamble$main_data,
+        remarks = remarks,
         data_row = data_row,
         user_remarks = user_remarks
     )
 
+    # Process the user constant rows
+    exdf_obj <- process_user_constant_rows_6800_excel(exdf_obj)
+
     # Check for columns that are all zero
     all_zeros <- sapply(check_for_zero, function(cn) {
         all(exdf_obj[, cn] == 0)
