@@ -1,3 +1,57 @@
+# Helping function for processing user constants that were logged as rows
+process_user_constant_rows_6800_plaintext <- function(licor_file) {
+    # In user constant rows, the first column has a text value formatted like
+    # "category:name". This can be used to identify the rows.
+    uc_rows <- sapply(seq_len(nrow(licor_file)), function(i) {
+        grepl('^[[:alnum:]]+:', licor_file[i, 1])
+    })
+
+    # Get the indices of user constant rows
+    uc_row_indx <- which(uc_rows)
+
+    # Process the user constant rows if there are any
+    if (length(uc_row_indx) > 0) {
+        # Update the main table following each user constant row
+        for (i in uc_row_indx) {
+            # The second column contains the user constant value
+            uc_val  <- licor_file[i, 2]
+
+            # Extract the name and category from the first column
+            uc_info     <- strsplit(licor_file[i, 1], ':')[[1]]
+            uc_name     <- uc_info[2]
+            uc_category <- uc_info[1]
+
+            # If this column is present in the main data table, update its value
+            # in this row and all following rows
+            uc_exists <- uc_name %in% colnames(licor_file) &&
+                licor_file[['categories']][[uc_name]] == uc_category
+
+            if (uc_exists) {
+                new_vals                           <- licor_file[, uc_name]
+                new_vals[seq(i, nrow(licor_file))] <- uc_val
+                licor_file[, uc_name]              <- new_vals
+            }
+        }
+
+        # Remove the user constant rows from the data table
+        licor_file <- licor_file[!uc_rows, , TRUE]
+
+        # Make sure there are no row names
+        rownames(licor_file$main_data) <- NULL
+
+        # The user-constant rows may have prevented some columns from being
+        # properly identified as having numeric values, so try to convert them
+        # again
+        for (i in seq_len(ncol(licor_file))) {
+            licor_file[['main_data']][, i] <-
+                try_as_numeric(licor_file[['main_data']][, i])
+        }
+    }
+
+    # Return the (potentially) modified version of the exdf object
+    licor_file
+}
+
 # Helping function for adding user remarks to the main data table (also used
 # for LI-6800 Excel files)
 add_latest_remark <- function(licor_file) {
@@ -78,6 +132,43 @@ licor_6800_lines_to_df <- function(file_lines, rows) {
   as.data.frame(chunk_res, stringsAsFactors = FALSE)
 }
 
+# Helping function for extracting the "preamble" and "remarks" from the header
+# info; the preamble is returned as an exdf, and the remarks as a data frame
+process_6800_plaintext_header <- function(header_df) {
+    # The "preamble" lines begin with "category:name"
+    preamble_indx <- grepl('^[[:alnum:]]+:', colnames(header_df))
+    preamble      <- header_df[1, preamble_indx]
+
+    # Extract the preamble names and categories
+    preamble_split <- strsplit(colnames(preamble), ':')
+    preamble_cat   <- sapply(preamble_split, function(x) {x[1]})
+    preamble_names <- sapply(preamble_split, function(x) {x[2]})
+
+    # Rename the preamble columns
+    colnames(preamble) <- preamble_names
+
+    # Assemble the preamble categories
+    preamble_categories      <- preamble
+    preamble_categories[1, ] <- preamble_cat
+
+    # Create the preamble exdf
+    preamble_exdf <- exdf(preamble, categories = preamble_categories)
+
+    # Remove any row names that may have been added
+    rownames(preamble_exdf$main_data)  <- NULL
+    rownames(preamble_exdf$units)      <- NULL
+    rownames(preamble_exdf$categories) <- NULL
+
+    # The remaining lines in the header are "remarks" lines
+    remarks <- header_df[1, !preamble_indx]
+
+    # Return both tables
+    list(
+      preamble_exdf = preamble_exdf,
+      remarks = remarks
+    )
+}
+
 # Main function for reading plaintext LI-6800 log files
 read_licor_6800_plaintext <- function(
     file_name,
@@ -166,6 +257,14 @@ read_licor_6800_plaintext <- function(
             stringsAsFactors = FALSE
         )
 
+        # Remove NA rows if necessary
+        if (remove_NA_rows) {
+            all_NA <- sapply(seq_len(nrow(licor_data)), function(i) {
+                all(is.na(as.list(licor_data[i, ])))
+            })
+            licor_data <- licor_data[!all_NA, ]
+        }
+
         # Get the column names as a vector
         licor_variable_names <-
             make.unique(as.character(licor_variable_names[1, ]))
@@ -197,16 +296,22 @@ read_licor_6800_plaintext <- function(
           seq(header_indx + 1, length.out = nlines)
         )
 
-        licor_preamble <- stats::setNames(
-            as.data.frame(
-                t(preamble_raw[, seq(2, ncol(preamble_raw))]),
-                stringsAsFactors = FALSE
-            ),
-            preamble_raw[, 1]
+        # Get just the values (as numeric when possible), and add the names
+        licor_preamble <- as.data.frame(
+            t(preamble_raw[, seq(2, ncol(preamble_raw))]),
+            stringsAsFactors = FALSE
         )
 
+        licor_preamble <- as.data.frame(
+            lapply(licor_preamble, try_as_numeric),
+            stringsAsFactors = FALSE
+        )
+
+        colnames(licor_preamble) <- preamble_raw[, 1]
+
+        # Replace any unicode
         colnames(licor_preamble) <- replace_unicode(colnames(licor_preamble))
-        licor_preamble[1, ] <- replace_unicode(licor_preamble[1, ])
+        licor_preamble[1, ]      <- replace_unicode(licor_preamble[1, ])
 
         licor_preamble
     })
@@ -228,18 +333,22 @@ read_licor_6800_plaintext <- function(
     exdf_obj    <- do.call(rbind, data_chunks)
     header_part <- do.call(rbind, header_chunks)
 
-    # Remove NA rows if necessary
-    if (remove_NA_rows) {
-        all_NA <- sapply(seq_len(nrow(exdf_obj)), function(i) {
-            all(is.na(as.list(exdf_obj[i, ])))
-        })
-        exdf_obj <- exdf_obj[!all_NA, , TRUE]
-    }
+    # Process the header
+    processed_header <- process_6800_plaintext_header(header_part)
+    preamble_exdf    <- processed_header$preamble_exdf
+    remarks          <- processed_header$remarks
+
+    # Incorporate preamble info into the main data table
+    exdf_obj <- cbind(exdf_obj, preamble_exdf)
 
     # Store additional information in the data exdf
-    exdf_obj$preamble     <- header_part
+    exdf_obj$preamble     <- preamble_exdf$main_data
+    exdf_obj$remarks      <- remarks
     exdf_obj$user_remarks <- user_remarks
 
+    # Process the user constant rows
+    exdf_obj <- process_user_constant_rows_6800_plaintext(exdf_obj)
+
     # Add user remarks if necessary
     if (include_user_remark_column) {
         exdf_obj <- add_latest_remark(exdf_obj)
