@@ -60,3 +60,19 @@ test_that('basic stats have not changed (not removing NA)', {
         tolerance = TOLERANCE
     )
 })
+
+test_that('basic stats can be calculated for columns with punctuation in their names', {
+    weird_df <- data.frame(
+        `a:1` = seq(1, 4),
+        `b/2` = seq(2, 5),
+        `d-3` = seq(3, 6),
+        e     = c('s1', 's1', 's2', 's2'),
+        check.names = FALSE
+    )
+
+    weird_exdf <- exdf(weird_df)
+
+    res <- expect_silent(
+        basic_stats(weird_exdf, 'e')
+    )
+})
